@@ -7,17 +7,18 @@ installXLSXsupport <- function(perl="perl", verbose=FALSE)
     findPerl(verbose = verbose)
   else
     findPerl(perl, verbose = verbose)
-  
+
   ##
   ## directories
   package.dir <- find.package('gdata')
   perl.dir <- file.path(package.dir,'perl')
+  temp.dir <- tempdir()
   ##
   ##
 
   cmd <- "install_modules.pl"
   sc <- file.path(perl.dir, cmd)
-  
+
   ##
   ##
 
@@ -53,6 +54,6 @@ installXLSXsupport <- function(perl="perl", verbose=FALSE)
   else
 	{
         	stop("\nUnable to install Perl XLSX support libraries.\n\n")
-		invisible(FALSE)                
-	}		
+		invisible(FALSE)
+	}
 }
