@@ -1,4 +1,4 @@
-# $Id: nobs.R 1564 2012-06-13 01:10:28Z warnes $
+# $Id: nobs.R 1799 2014-04-05 18:38:23Z warnes $
 
 ## Redefine here, so that the locally defined methods (particularly
 ## nobs.default) take precidence over the ones now defined in the
@@ -11,9 +11,9 @@ nobs.default <- function(object, ...)
     if(is.numeric(object) || is.logical(object))
       sum( !is.na(object) )
     else
-      stats:::nobs.default(object, ...)
+      stats::nobs(object, ...)
   }
-    
+
 
 nobs.data.frame <- function(object, ...)
   sapply(object, nobs.default)
